Animanager Documentation
========================

Animanager_ is a command line program for advanced anime watching management.

.. _Animanager: https://darkfeline.github.io/animanager/

.. toctree::
   :maxdepth: 1

   install
   quickstart

Indices and tables
==================

- :ref:`genindex`
- :ref:`modindex`
- :ref:`search`
